@@ -23,6 +23,8 @@
 #include <boost/spirit/iterator/fixed_size_queue.hpp>
 #include <boost/detail/iterator.hpp> // for boost::detail::iterator_traits
 
+#include <boost/spirit/iterator/multi_pass_fwd.hpp>
+
 namespace boost { namespace spirit {
 
 namespace impl {
@@ -262,7 +264,7 @@ class inner
         // will be called from the destructor of the last iterator.
         void destroy()
         {
-            BOOST_SPIRIT_ASSERT(queuedElements);
+            BOOST_SPIRIT_ASSERT(NULL != queuedElements);
             delete queuedElements;
             queuedElements = 0;
         }
@@ -401,7 +403,7 @@ class inner
         // will be called from the destructor of the last iterator.
         void destroy()
         {
-            BOOST_SPIRIT_ASSERT(queuedElements);
+            BOOST_SPIRIT_ASSERT(NULL != queuedElements);
             delete queuedElements;
             queuedElements = 0;
         }
@@ -500,6 +502,12 @@ class inner
             bool was_initialized;
         };
 
+       // Needed by compilers not implementing the resolution to DR45. For
+       // reference, see
+       // http://www.open-std.org/JTC1/SC22/WG21/docs/cwg_defects.html#45.
+
+       friend struct Data;
+
     public:
         typedef result_type value_type;
         typedef
@@ -555,14 +563,14 @@ class inner
     public:
         reference get_input() const
         {
-            BOOST_SPIRIT_ASSERT(0 != data);
+            BOOST_SPIRIT_ASSERT(NULL != data);
             ensure_initialized();
             return data->curtok;
         }
 
         void advance_input()
         {
-            BOOST_SPIRIT_ASSERT(0 != data);
+            BOOST_SPIRIT_ASSERT(NULL != data);
             data->was_initialized = false;        // should get the next token
             ++data->input;
         }
@@ -768,26 +776,11 @@ struct iterator_base_creator
 
 }}
 
-
-
 ///////////////////////////////////////////////////////////////////////////////
-// class template multi_pass (declaration)
+// class template multi_pass 
 ///////////////////////////////////////////////////////////////////////////////
-template
-<
-    typename InputT,
-    typename InputPolicy = multi_pass_policies::input_iterator,
-    typename OwnershipPolicy = multi_pass_policies::ref_counted,
-    typename CheckingPolicy = multi_pass_policies::buf_id_check,
-    typename StoragePolicy = multi_pass_policies::std_deque
->
-class multi_pass;
 
 // The default multi_pass instantiation uses a ref-counted std_deque scheme.
-
-///////////////////////////////////////////////////////////////////////////////
-// class template multi_pass (definition)
-///////////////////////////////////////////////////////////////////////////////
 template
 <
     typename InputT,
