@@ -1417,6 +1417,7 @@ po_extra_files = Split('''
     sv.po
     tr.po
     wa.po
+    uk.po
     zh_CN.po
     zh_TW.po
 ''')
@@ -1507,6 +1508,7 @@ lib_templates_files = Split('''
     ijmpc.lyx
     ijmpd.lyx
     iop-article.lyx
+    JSS-article.lyx
     kluwer.lyx
     koma-letter2.lyx
     latex8.lyx
@@ -2580,7 +2582,6 @@ lib_examples_es_files = Split('''
     ItemizeBullets.lyx
     ejemplo_con_lyx.lyx
     ejemplo_sin_lyx.lyx
-    mathed.lyx
     splash.lyx
 ''')
 
@@ -2738,6 +2739,7 @@ lib_layouts_files = Split('''
     iopart.layout
     isprs.layout
     jgrga.layout
+    jss.layout
     kluwer.layout
     latex8.layout
     letter.layout
@@ -2978,29 +2980,6 @@ development_Win32_packaging_installer = Split('''
     license.rtf
     lyx.nsi
     settings.nsh
-    settings.user.nsh
-''')
-
-
-development_Win32_packaging_installer_components = Split('''
-    configure.nsh
-    core.nsh
-    dicts.nsh
-    external.nsh
-    langselect.nsh
-    reinstall.nsh
-    uninstall.nsh
-    user.nsh
-    viewer.nsh
-''')
-
-
-development_Win32_packaging_installer_dialogs = Split('''
-    external.ini
-    langselect.ini
-    reinstall.ini
-    user.ini
-    viewer.ini
 ''')
 
 
@@ -3010,14 +2989,23 @@ development_Win32_packaging_installer_graphics = Split('''
 ''')
 
 
+development_Win32_packaging_installer_gui = Split('''
+    external.nsh
+    langselect.nsh
+    reinstall.nsh
+''')
+
+
 development_Win32_packaging_installer_include = Split('''
     declarations.nsh
     detection.nsh
-    filelists.nsh
+    dictlist.nsh    
+    filelist.nsh
     gui.nsh
     init.nsh
-    lang.nsh
-    windows.nsh
+    langlist.nsh
+    nsis.nsh
+    variables.nsh
 ''')
 
 
@@ -3028,3 +3016,9 @@ development_Win32_packaging_installer_lang = Split('''
     italian.nsh
 ''')
 
+
+development_Win32_packaging_installer_setup = Split('''
+    configure.nsh
+    install.nsh
+    reinstall.nsh
+''')
