@@ -117,7 +117,7 @@ def env_nsis(source, target, env, for_signature):
             ret += ' '
     # bundled?
     if '-bundle.exe' in str(target[0]):
-        ret += '/DSETUPTYPE_BUNDLE=1 '
+        ret += '/DSETUPTYPE=BUNDLE '
     for s in source:
         ret += quoteIfSpaced(str(s))
     return ret
@@ -228,7 +228,7 @@ int main()
 }
 '''
     conf.Message('Checking for the use of global cstd... ')
-    ret = conf.TryLink(check_global_cstd_source, '.c')
+    ret = conf.TryLink(check_global_cstd_source, '.cpp')
     conf.Result(ret)
     return ret
 
@@ -407,7 +407,7 @@ int main() {
 }
 '''
     conf.Message('Checking if the declaration of iconv needs const... ')
-    ret = conf.TryLink(check_iconv_const, '.c')
+    ret = conf.TryLink(check_iconv_const, '.cpp')
     conf.Result(ret)
     return ret
 
