@@ -83,22 +83,6 @@ CutStack selectionBuffer(1);
 bool dirty_tabular_stack_ = false;
 
 
-void region(CursorSlice const & i1, CursorSlice const & i2,
-	Inset::row_type & r1, Inset::row_type & r2,
-	Inset::col_type & c1, Inset::col_type & c2)
-{
-	Inset & p = i1.inset();
-	c1 = p.col(i1.idx());
-	c2 = p.col(i2.idx());
-	if (c1 > c2)
-		std::swap(c1, c2);
-	r1 = p.row(i1.idx());
-	r2 = p.row(i2.idx());
-	if (r1 > r2)
-		std::swap(r1, r2);
-}
-
-
 bool checkPastePossible(int index)
 {
 	return size_t(index) < theCuts.size() && !theCuts[index].first.empty();
@@ -287,7 +271,7 @@ pasteSelectionHelper(Cursor & cur, ParagraphList const & parlist,
 PitPosPair eraseSelectionHelper(BufferParams const & params,
 	ParagraphList & pars,
 	pit_type startpit, pit_type endpit,
-	int startpos, int endpos, bool doclear)
+	int startpos, int endpos)
 {
 	// Start of selection is really invalid.
 	if (startpit == pit_type(pars.size()) ||
@@ -303,12 +287,6 @@ PitPosPair eraseSelectionHelper(BufferParams const & params,
 	for (pit_type pit = startpit; pit != endpit + 1;) {
 		pos_type const left  = (pit == startpit ? startpos : 0);
 		pos_type right = (pit == endpit ? endpos : pars[pit].size() + 1);
-		// FIXME: this is a quick fix for bug 3600. It stops a crash but the problem
-		// still remains unsolved (e.g. the second example in the bug report).
-		// c.f. http://bugzilla.lyx.org/show_bug.cgi?id=3600
-		if (right > pars[pit].size() + 1)
-			right = pars[pit].size() + 1;
-
 		bool const merge = pars[pit].isMergedOnEndOfParDeletion(params.trackChanges);
 
 		// Logically erase only, including the end-of-paragraph character
@@ -316,14 +294,13 @@ PitPosPair eraseSelectionHelper(BufferParams const & params,
 
 		// Separate handling of paragraph break:
 		if (merge && pit != endpit &&
-		    (pit + 1 != endpit || pars[pit].hasSameLayout(pars[pit + 1]))) {
-			pos_type const thissize = pars[pit].size();
-			if (doclear)
-				pars[pit + 1].stripLeadingSpaces(params.trackChanges);
+		    (pit + 1 != endpit 
+		     || pars[pit].hasSameLayout(pars[endpit])
+		     || pars[endpit].size() == endpos)) {
+			if (pit + 1 == endpit)
+				endpos += pars[pit].size();
 			mergeParagraph(params, pars, pit);
 			--endpit;
-			if (pit == endpit)
-				endpos += thissize;
 		} else
 			++pit;
 	}
@@ -401,6 +378,22 @@ void copySelectionHelper(Buffer const & buf, ParagraphList & pars,
 
 namespace cap {
 
+void region(CursorSlice const & i1, CursorSlice const & i2,
+	Inset::row_type & r1, Inset::row_type & r2,
+	Inset::col_type & c1, Inset::col_type & c2)
+{
+	Inset & p = i1.inset();
+	c1 = p.col(i1.idx());
+	c2 = p.col(i2.idx());
+	if (c1 > c2)
+		std::swap(c1, c2);
+	r1 = p.row(i1.idx());
+	r2 = p.row(i2.idx());
+	if (r1 > r2)
+		std::swap(r1, r2);
+}
+
+
 docstring grabAndEraseSelection(Cursor & cur)
 {
 	if (!cur.selection())
@@ -411,6 +404,23 @@ docstring grabAndEraseSelection(Cursor & cur)
 }
 
 
+bool multipleCellsSelected(Cursor const & cur)
+{
+	if (!cur.selection() || !cur.inMathed())
+		return false;
+	
+	CursorSlice i1 = cur.selBegin();
+	CursorSlice i2 = cur.selEnd();
+	if (!i1.inset().asInsetMath())
+		return false;
+	
+	if (i1.idx() == i2.idx())
+		return false;
+	
+	return true;
+}
+
+
 void switchBetweenClasses(textclass_type c1, textclass_type c2,
 	InsetText & in, ErrorList & errorlist)
 {
@@ -553,8 +563,7 @@ void cutSelection(Cursor & cur, bool doclear, bool realcut)
 			eraseSelectionHelper(bp,
 				text->paragraphs(),
 				begpit, endpit,
-				cur.selBegin().pos(), endpos,
-				doclear);
+				cur.selBegin().pos(), endpos);
 
 		// cutSelection can invalidate the cursor so we need to set
 		// it anew. (Lgb)
@@ -702,6 +711,12 @@ void clearSelection()
 }
 
 
+void clearCutStack()
+{
+	theCuts.clear();
+}
+
+
 docstring getSelection(Buffer const & buf, size_t sel_index)
 {
 	return sel_index < theCuts.size()
