@@ -14,13 +14,17 @@
 #define LATEXFEATURES_H
 
 
-#include "outputparams.h"
+#include "OutputParams.h"
+#include "support/docstring.h"
 
 #include <set>
 #include <list>
 #include <map>
 #include <string>
 
+
+namespace lyx {
+
 class Buffer;
 class BufferParams;
 class Language;
@@ -35,14 +39,14 @@ class Language;
  *  packages which don't have special requirements are handled automatically.
  *  If your new package does need special consideration you'll need to alter
  *  string const getPackages() const;
- *  Remember to update the validate function in buffer.C and paragraph.C
+ *  Remember to update the validate function in Buffer.cpp and Paragraph.cpp
  *  when you do so.
  */
 class LaTeXFeatures {
 public:
 	///
 	LaTeXFeatures(Buffer const &, BufferParams const &,
-	              OutputParams const &);
+		      OutputParams const &);
 	/// The packages needed by the document
 	std::string const getPackages() const;
 	/// The macros definitions needed by the document
@@ -50,27 +54,32 @@ public:
 	///
 	std::string const getBabelOptions() const;
 	/// The definitions needed by the document's textclass
-	std::string const getTClassPreamble() const;
-	/// The sgml definitions needed by the document (dobook/linuxdoc)
-	std::string const getLyXSGMLEntities() const;
+	docstring const getTClassPreamble() const;
+	/// The sgml definitions needed by the document (docbook)
+	docstring const getLyXSGMLEntities() const;
 	/// The SGML Required to include the files added with includeFile();
-	std::string const getIncludedFiles(std::string const & fname) const;
+	docstring const getIncludedFiles(std::string const & fname) const;
 	/// Include a file for use with the SGML entities
-	void includeFile(std::string const & key, std::string const & name);
+	void includeFile(docstring const & key, std::string const & name);
 	/// The float definitions.
 	void getFloatDefinitions(std::ostream & os) const;
 	/// Print requirements to lyxerr
 	void showStruct() const;
 	///
-	void addExternalPreamble(std::string const &);
+	void addPreambleSnippet(std::string const &);
 	/// Provide a string name-space to the requirements
 	void require(std::string const & name);
 	/// Which of the required packages are installed?
 	static void getAvailable();
-	/// Is the package required?
-	bool isRequired(std::string const & name) const;
 	/// Is the (required) package available?
-	bool isAvailable(std::string const & name) const;
+	static bool isAvailable(std::string const & name);
+	/// Has the package been required?
+	bool isRequired(std::string const & name) const;
+	/* Is it necessary to load the package? This is true if
+	   isRequired is true and the feature is not provided by the
+	   textclass.
+	*/
+	bool mustProvide(std::string const & name) const;
 	///
 	void useFloat(std::string const & name);
 	///
@@ -82,7 +91,7 @@ public:
 	///
 	std::set<std::string> getEncodingSet(std::string const & doc_encoding) const;
 	///
-	void useLayout(std::string const & lyt);
+	void useLayout(docstring const & lyt);
 	///
 	Buffer const & buffer() const;
 	///
@@ -95,7 +104,7 @@ public:
 	OutputParams const & runparams() const { return runparams_; }
 
 private:
-	std::list<std::string> usedLayouts_;
+	std::list<docstring> usedLayouts_;
 
 	/// Static preamble bits from the external material insets
 	typedef std::list<std::string> FeaturesList;
@@ -109,14 +118,14 @@ private:
 	static PackagesList packages_;
 	///
 	typedef std::set<Language const *> LanguageList;
-	///
+	/// used languages (only those that are supported by babel)
 	LanguageList UsedLanguages_;
 	///
 	typedef std::set<std::string> UsedFloats;
 	///
 	UsedFloats usedFloats_;
 	///
-	typedef std::map<std::string , std::string> FileMap;
+	typedef std::map<docstring , std::string> FileMap;
 	///
 	FileMap IncludedFiles_;
 	/** Buffer of the file being processed.
@@ -133,4 +142,7 @@ private:
 	OutputParams const & runparams_;
 };
 
+
+} // namespace lyx
+
 #endif
