@@ -55,6 +55,7 @@ public:
 		RC_CONVERTER_CACHE_MAXAGE,
 		RC_COPIER,
 		RC_CURSOR_FOLLOWS_SCROLLBAR,
+		RC_MAC_LIKE_WORD_MOVEMENT,
 		RC_CUSTOM_EXPORT_COMMAND,
 		RC_CUSTOM_EXPORT_FORMAT,
 		RC_DATE_INSERT_FORMAT,
@@ -335,6 +336,8 @@ public:
 	///
 	std::string default_language;
 	///
+	bool mac_like_word_movement;
+	///
 	bool cursor_follows_scrollbar;
 	///
 	bool dialogs_iconify_with_main;
