@@ -336,17 +336,18 @@ RowMetrics TextMetrics::computeRowMetrics(pit_type const pit,
 		// The test on par.size() is to catch zero-size pars, which
 		// would trigger the assert in Paragraph::getInset().
 		//inset = par.size() ? par.getInset(row.pos()) : 0;
-		if (row.pos() < par.size()
-		    && par.isInset(row.pos()))
-		{
-		    switch(par.getInset(row.pos())->display()) {
+		if (row.pos() < par.size() && par.isInset(row.pos())) {
+			switch(par.getInset(row.pos())->display()) {
 			case Inset::AlignLeft:
 				align = LYX_ALIGN_BLOCK;
 				break;
 			case Inset::AlignCenter:
 				align = LYX_ALIGN_CENTER;
 				break;
-			// other types unchanged (use align)
+			case Inset::Inline:
+			case Inset::AlignRight:
+				// unchanged (use align)
+				break;
 			}
 		}
 
@@ -893,9 +894,10 @@ pos_type TextMetrics::getColumnNearX(pit_type const pit,
 	bool const rtl = lastrow ? text_->isRTL(buffer, par) : false;
 	if (lastrow &&
 	    ((rtl  &&  left_side && vc == row.pos() && x < tmpx - 5) ||
-	     (!rtl && !left_side && vc == end  && x > tmpx + 5)))
-		c = end;
-	else if (vc == row.pos()) {
+	     (!rtl && !left_side && vc == end  && x > tmpx + 5))) {
+		if (!par.isNewline(end - 1))
+			c = end;
+	} else if (vc == row.pos()) {
 		c = bidi.vis2log(vc);
 		if (bidi.level(c) % 2 == 1)
 			++c;
