@@ -15,6 +15,7 @@
 #include "InsetNote.h"
 
 #include "Buffer.h"
+#include "BufferParams.h"
 #include "BufferView.h"
 #include "Cursor.h"
 #include "debug.h"
@@ -160,6 +161,18 @@ Inset::DisplayType InsetNote::display() const
 }
 
 
+bool InsetNote::metrics(MetricsInfo & mi, Dimension & dim) const
+{
+	Font tmpfont = mi.base.font;
+	mi.base.font = mi.base.bv->buffer()->params().getFont();
+	InsetCollapsable::metrics(mi, dim);
+	mi.base.font = tmpfont;
+	bool const changed = dim_ != dim;
+	dim_ = dim;
+	return changed;
+}
+
+
 void InsetNote::write(Buffer const & buf, ostream & os) const
 {
 	params_.write(os);
