@@ -73,8 +73,7 @@ public:
 	int docbook(Buffer const &, odocstream &,
 		    OutputParams const &) const;
 	/// the string that is passed to the TOC
-	virtual int textString(Buffer const &, odocstream &,
-		OutputParams const &) const;
+	void textString(Buffer const &, odocstream &) const;
 	///
 	Inset::Code lyxCode() const { return Inset::SPACE_CODE; }
 	/// We don't need \begin_inset and \end_inset
