@@ -15,7 +15,10 @@
 #ifndef LENGTH_COMMON_H
 #define LENGTH_COMMON_H
 
-#include "lyxlength.h"
+#include "Length.h"
+
+
+namespace lyx {
 
 
 /// the number of units possible
@@ -28,10 +31,12 @@ extern int const num_units;
  */
 extern char const * const unit_name[];
 extern char const * const unit_name_gui[];
-extern char const * const unit_name_ltx[];
 
 /// return the unit given a string representation such as "cm"
-LyXLength::UNIT unitFromString(std::string const & data);
+Length::UNIT unitFromString(std::string const & data);
 
 
+
+} // namespace lyx
+
 #endif // LENGTH_COMMON_H
