@@ -35,8 +35,6 @@ public:
 	mode_type currentMode() const { return TEXT_MODE; }
 private:
 	virtual std::auto_ptr<Inset> doClone() const;
-	/// width of '[' in current font
-	mutable int w_;
 };
 
 
