@@ -12,7 +12,10 @@
 #ifndef MATH_FACTORY_H
 #define MATH_FACTORY_H
 
+#include "MathParser.h"
 #include "support/docstring.h"
+
+#include <map>
 #include <string>
 
 namespace lyx {
@@ -30,6 +33,8 @@ MathAtom createInsetMath(char const * const);
  */
 bool createInsetMath_fromDialogStr(docstring const &, MathData &);
 
+typedef std::map<docstring, latexkeys> WordList;
+WordList const & mathedWordList();
 
 } // namespace lyx
 
