@@ -12,9 +12,17 @@
 #ifndef OUTPUT_H
 #define OUTPUT_H
 
-#include <iosfwd>
-#include <string>
+#include "support/docstream.h"
 
-bool openFileWrite(std::ofstream & ofs, std::string const & fname);
+
+namespace lyx {
+
+namespace support { class FileName; }
+
+bool openFileWrite(std::ofstream & ofs, support::FileName const & fname);
+bool openFileWrite(odocfstream & ofs, support::FileName const & fname);
+
+
+} // namespace lyx
 
 #endif
